@@ -257,7 +257,7 @@
   (sit-for 0)
   (display-message
    'no-log
-   (format "Func-Menu version %s")))
+   (format "Func-Menu version %s" fume-version)))
 
 (defconst fume-running-xemacs (string-match "XEmacs\\|Lucid" emacs-version))
 
@@ -575,7 +575,7 @@ called if `fume-fn-window-position' is nil or invalid. Default is nil.")
 Usage:
 By default, `fume-auto-rescan-buffer-p' is set to t. If a particular
 major-mode slows down too much as a result of automatic rescanning
-by func-menu, add someting like the following:
+by func-menu, add something like the following:
 
    (defun remove-func-menu-auto-rescan ()
       (setq fume-auto-rescan-buffer-p nil))
@@ -962,12 +962,13 @@ can be very slow for large or non-trivial Makefiles.
   "^\\(task\\|function\\|module\\|primitive\\)[ \t]+\\([A-Za-z0-9_+-]*\\)[ \t]*(?"
   "Expression to get verilog module names")
 
-;;; Idl
+;;; IDL (Interactive Data Language)
 ;;;
 ;;; Lubos Pochman <lubos@rsinc.com>
-(defvar fume-function-name-regexp-idl
-  (cons "^\\s *\\([pP][rR][oO]\\|[fF][uU][nN][cC][tT][iI][oO][nN]\\)\\s +\\([A-Za-z][A-Za-z0-9_$]*\\)" 2)
-  "Expression to get Idl function Names")
+;;; Carsten Dominik <dominik@astro.uva.nl>
+(defvar fume-function-name-regexp-idlwave
+  (cons "^\\s *\\([pP][rR][oO]\\|[fF][uU][nN][cC][tT][iI][oO][nN]\\)\\s +\\([A-Za-z][A-Za-z0-9_$]*\\(::[A-Za-z][A-Za-z0-9_$]*\\)?\\)" 2)
+  "Expression to get IDL function, procedure and method names.")
 
 ;;; Assembly
 (defvar fume-function-name-regexp-asm
@@ -1076,8 +1077,8 @@ can be very slow for large or non-trivial Makefiles.
     ;; Verilog
     (verilog-mode . fume-function-name-regexp-verilog)
 
-    ;; Idl
-    (idl-mode . fume-function-name-regexp-idl)
+    ;; IDL (Interactive Data Language)
+    (idlwave-mode . fume-function-name-regexp-idlwave)
 
     ;; Assembly
     (asm-mode . fume-function-name-regexp-asm)
@@ -1554,18 +1555,18 @@ can be very slow for large or non-trivial Makefiles.
             (end (match-end 2)))
         (cons (buffer-substring beg end) beg))))
 
-;;; Specialised routine to get the next idl function in the buffer
+;;; Specialised routine to get the next IDL function in the buffer
 ;;;
 ;;; Lubos Pochman <lubos@rsinc.com>
-(defun fume-find-next-idl-function-name (buffer)
-  "Searches for the next idl function in BUFFER."
+;;; Carsten Dominik <dominik@astro.uva.nl>
+(defun fume-find-next-idlwave-function-name (buffer)
+  "Searches for the next IDL function in BUFFER."
   (set-buffer buffer)
-  (if (re-search-forward (car fume-function-name-regexp-idl) nil t)
-      (let ((beg (match-beginning (cdr fume-function-name-regexp-idl)))
-            (end (match-end (cdr fume-function-name-regexp-idl))))
+  (if (re-search-forward (car fume-function-name-regexp-idlwave) nil t)
+      (let ((beg (match-beginning (cdr fume-function-name-regexp-idlwave)))
+            (end (match-end (cdr fume-function-name-regexp-idlwave))))
         (cons (buffer-substring beg end) beg))))
 
-
 ;;; Assembly
 ;;; Bob Weiner <weiner@altrasoft.com>
 ;;;
@@ -1625,7 +1626,7 @@ can be very slow for large or non-trivial Makefiles.
     (sgml-mode       . fume-find-next-sgml-element-name)
     (tcl-mode        . fume-match-find-next-function-name)
     (verilog-mode    . fume-find-next-verilog-function-name)
-    (idl-mode        . fume-find-next-idl-function-name)
+    (idlwave-mode    . fume-find-next-idlwave-function-name)
     (Manual-mode     . fume-find-next-manual-section)
     )
 
