@@ -1,5 +1,5 @@
 ;;; recent-files.el --- Maintain menu of recently opened files.
-;;; $Header: /usr/CVSroot/XEmacs/xemacs-packages/oa/edit-utils/recent-files.el,v 1.3 1999/05/13 14:23:11 steveb Exp $
+;;; $Header: /usr/CVSroot/XEmacs/xemacs-packages/oa/edit-utils/recent-files.el,v 1.4 2000/10/06 09:08:01 youngs Exp $
 ;;;
 ;;; Copyright (C) 1994, 1995 Juergen Nickelsen <nickel@cs.tu-berlin.de>
 ;;;
@@ -246,7 +246,7 @@ are not applied in the latter case."
 
 (defcustom recent-files-filename-replacements
   (list (cons (regexp-quote (expand-file-name "~")) "~"))
-  "*List of regexp/replacement pairs for filename filenamees.
+  "*List of regexp/replacement pairs for filename filenames.
 If a filename of a filename matches one of the regexps, it is replaced
 by the corresponding replacement."
   :type '(repeat (cons regexp (string :tag "Replacement")))
@@ -334,7 +334,7 @@ This value is toggled by a menu entry.")
 
 (defvar recent-files-list nil
   "List of recently opened files.
-Entries are pairs like (<filename> . <permant-p>).
+Entries are pairs like (<filename> . <permanent-p>).
 If <permanent-p> is non-nil, the file stays permanently in the list.")
 
 (defvar recent-files-commands-menu
@@ -413,10 +413,10 @@ If the buffer has changed, the menu must be rebuilt.")
 
 
 (defun recent-files-version ()
-  "Return a string identifying the current verion of recent-files.
+  "Return a string identifying the current version of recent-files.
 If called interactively, show it in the echo area."
   (interactive)
-  (let ((version "$Header: /usr/CVSroot/XEmacs/xemacs-packages/oa/edit-utils/recent-files.el,v 1.3 1999/05/13 14:23:11 steveb Exp $"))
+  (let ((version "$Header: /usr/CVSroot/XEmacs/xemacs-packages/oa/edit-utils/recent-files.el,v 1.4 2000/10/06 09:08:01 youngs Exp $"))
     (if (interactive-p)
 	(message version)
       version)))
@@ -600,7 +600,7 @@ the file."
 
 (defun recent-files-replace-filenames (filename)
   "Replace the part of FILENAME that matches a regular expression
-in recent-files-filename-replacements with the corrensponding replacement.
+in recent-files-filename-replacements with the corresponding replacement.
 If FILENAME does not match any regular expression, return it unchanged.
 Only the first matching regexp/replacement pair is applied."
   (let ((replist recent-files-filename-replacements)
